@@ -1,6 +1,7 @@
 import io
 import base64
 import logging
+import re
 
 from barcode import generate
 import unidecode
@@ -13,16 +14,17 @@ def generate_barcode_b64image(barcode_number, text=None):
     buffer = io.BytesIO()
     generate(name="itf", code=barcode_number, output=buffer, text=text)
     base64_img = base64.b64encode(buffer.getvalue())
-    return base64_img
+    return base64_img.decode("utf-8")
 
 
-def parse_unicode_to_ascii(string):
+def parse_unicode_to_alphanumeric(string):
     """
     Método para transliterar um texto com caracteres especiais
     em um texto maiúsculo sem caracteres especiais.
     """
     ascii_string = unidecode.unidecode(string)
-    return ascii_string.upper()
+    alphanumeric_string = re.sub(r"[^A-Za-z0-9]", "", ascii_string)
+    return alphanumeric_string.upper()
 
 
 def _get_logger(name):
@@ -36,4 +38,3 @@ def _get_logger(name):
         novo logger para bb_wrapper.{name}
     """
     return logging.getLogger(f"bb_wrapper.{name}")
-
